# Size

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**is_unsupervised** | **bool** |  | [optional] [readonly] 
**managed_by** | **str** |  | 
**role** | **int** |  | 
**total_size** | **int** |  | [optional] [readonly] 
**smart_data_size** | **int** |  | [optional] [readonly] 
**total_size_available** | **int** |  | [optional] [readonly] 
**smart_data_size_available** | **int** |  | [optional] [readonly] 
**remaining_total_size** | **int** |  | [optional] [readonly] 
**remaining_smart_data_size** | **int** |  | [optional] [readonly] 
**remaining_total_size_percent** | **int** |  | [optional] [readonly] 
**remaining_smart_data_size_percent** | **int** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


